@@ -4,7 +4,7 @@ Name: filter_scale.py
 Porpose: Show dialog to get scale data based on FFmpeg syntax
 Compatibility: Python3, wxPython Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-Copyleft - 2024 Gianluca Pernigotto <jeanlucperni@gmail.com>
+Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
 Rev: Feb.21.2024
 Code checker: flake8, pylint
@@ -286,7 +286,6 @@ class Scale(wx.Dialog):
         if error:
             wx.MessageBox(f'{error}', _('Videomass - Error!'),
                           wx.ICON_ERROR, self)
-            return
 
     def keep_aspect_ratio_on(self):
         """
@@ -443,8 +442,10 @@ class Scale(wx.Dialog):
         Open default web browser via Python Web-browser controller.
         see <https://docs.python.org/3.8/library/webbrowser.html>
         """
-        page = ('https://jeanslack.github.io/Videomass/User-guide'
-                '/Video_filters_en.pdf')
+        page = ('https://jeanslack.github.io/Videomass/User-guide/'
+                'Video_filters_en.pdf#%5B%7B%22num%22%3A10%2C%22gen%22%'
+                '3A0%7D%2C%7B%22name%22%3A%22XYZ%22%7D%2C56.7%2C785.'
+                '189%2C0%5D')
 
         webbrowser.open(page)
     # ------------------------------------------------------------------#
